<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="../aboutdlg.cpp" line="28"/>
        <source>About Dust Racing</source>
        <translation>O hře Dust Racing</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="64"/>
        <source>Randomly rotate objects</source>
        <translation>Náhodně otočit předměty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Loading &apos;%1&apos;..</source>
        <translation>Nahrává se &apos;%1&apos;..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
        <translation>Vyberte Soubor -&gt; Nový nebo Soubor -&gt; Otevřít pro spuštění.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="120"/>
        <source>Save your work to correct location.</source>
        <translation>Uložte svou práci do správného umístění.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>To make the game find your circuits, save them to %1%2%3%2</source>
        <translation>Aby hra našla vaše okruhy, uložte je do %1%2%3%2</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>, %4%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>New file</source>
        <translation>Nový soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Scale:</source>
        <translation>Měřítko:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>ERROR!!: Cannot load objects from &apos;</source>
        <translation>Chyba: Nelze nahrát předměty z </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Scale set to %1%</source>
        <translation>Měřítko nastaveno na %1%</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>&amp;New...</source>
        <translation>&amp;Nový...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otevřít...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>&amp;Save as...</source>
        <translation>Uložit &amp;jako...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>&amp;Clear all</source>
        <translation type="vanished">&amp;Vyprázdnit vše</translation>
    </message>
    <message>
        <source>Enlarge hor size</source>
        <translation type="vanished">Zvětšit vodorovnou velikost</translation>
    </message>
    <message>
        <source>Enlarge ver size</source>
        <translation type="vanished">Zvětšit svislou velikost</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>&amp;Set properties..</source>
        <translation>Nastavit &amp;vlastnosti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="382"/>
        <source>&amp;Route</source>
        <translation>&amp;Cesta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Clear &amp;route</source>
        <translation>Vyprázdnit c&amp;estu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>&amp;Set route..</source>
        <translation>&amp;Nastavit cestu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="397"/>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Erase object</source>
        <translation>Vymazat předmět</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>Clear</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Open a track</source>
        <translation>Otevřít trať</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Track Files (*.trk)</source>
        <translation>Soubory s tratěmi (*.trk)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>ERROR!!: %1 doesn&apos;t exist.</source>
        <translation>Chyba: %1 neexistuje.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Track &apos;%1&apos; opened.</source>
        <translation>Trať &apos;%1&apos; otevřena.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Failed to open track &apos;</source>
        <translation>Nepodařilo se otevřít trať </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Track &apos;</source>
        <translation>Trať</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>&apos; saved.</source>
        <translation> uložena.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Failed to save track &apos;</source>
        <translation>Nepodařilo se uložit trať </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>Save a track</source>
        <translation>Uložit trať</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>Failed to save track as &apos;</source>
        <translation>Nepodařilo se uložit trať jako </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
        <translation>Nová trať %1 vytvořena. Sloupce: %2, řádky: %3.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Track properties updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index set to &apos;%1&apos;.</source>
        <translation type="vanished">Index nastaven na &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Set route: begin.</source>
        <translation>Nastavit cestu: začátek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Set route, checkpoints and driving lines.</source>
        <translation>Nastavit cestu, kontrolní body a jízdní dráhy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Setting the route defines checkpoints for the cars so
that no shortcuts can be taken. It also defines
driving lines for the computer players.

Click on the tiles one by one and make a closed loop
with the target nodes. You can adjust the nodes afterwads.
Start from the first tile after the finish line tile
to make the lap detection and timing work correctly.
Click on the first node again to finish.</source>
        <translation>Nastavení cesty stanovuje kontrolní body pro vozy,
takže není možné si cestu zkrátit. Také určuje
jízdní dráhy počítačem řízených hráčů.

Klepněte postupně na dlaždice a udělejte zavřenou smyčku
s cílovými uzly. Uzly můžete upravit i později.
Začněte od první dlaždice za dlaždicí s cílovou čárou,
abyste zajistili správné zjištění kola a času.
Klepněte znovu na první uzel pro dokončení.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Set route</source>
        <translation>Nastavit cestu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Invalid track. Route cannot be set.</source>
        <translation>Neplatná trať. Cestu nelze nastavit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Set route: not a valid track.</source>
        <translation>Nastavit cestu: neplatná trať.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Set route: route finished.</source>
        <translation>Nastavit cestu: cesta dokončena.</translation>
    </message>
</context>
<context>
    <name>NewTrackDialog</name>
    <message>
        <location filename="../newtrackdialog.cpp" line="29"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="30"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="34"/>
        <source>Number of tile columns:</source>
        <translation>Počet sloupců dlaždic:</translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="35"/>
        <source>Number of tile rows:</source>
        <translation>Počet řádků dlaždic:</translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="36"/>
        <source>Track name:</source>
        <translation>Název tratě:</translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="37"/>
        <source>User track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../newtrackdialog.cpp" line="40"/>
        <source>Create a new track</source>
        <translation>Vytvořit novou trať</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tiles cleared.</source>
        <translation type="vanished">Dlaždice vyprázdněny.</translation>
    </message>
    <message>
        <location filename="../editordata.cpp" line="377"/>
        <source>Route cleared.</source>
        <translation>Cesta vyprázdněna.</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <location filename="../editorview.cpp" line="95"/>
        <location filename="../editorview.cpp" line="107"/>
        <source>Rotate 90</source>
        <translation>Otočit o 90°</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="95"/>
        <source> CW..</source>
        <translation> po směru hodinových ručiček.</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="107"/>
        <source> CCW..</source>
        <translation> proti směru hodinových ručiček.</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="119"/>
        <source>Clear computer hint</source>
        <translation>Odstranit radu počítače</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="126"/>
        <source>Set computer hint &apos;brake hard&apos;..</source>
        <translation>Nastavit radu počítače Usilovně brzdit...</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="133"/>
        <source>Set computer hint &apos;brake&apos;..</source>
        <translation>Nastavit radu počítače Brzdit...</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="140"/>
        <source>Exclude from minimap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="151"/>
        <source>Insert row before..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="160"/>
        <source>Insert row after..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="169"/>
        <source>Delete row..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="178"/>
        <source>Insert column before..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="187"/>
        <source>Insert column after..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="196"/>
        <source>Delete column..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="225"/>
        <source>Rotate..</source>
        <translation>Otočit...</translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="240"/>
        <source>Force stationary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editorview.cpp" line="259"/>
        <source>Set size..</source>
        <translation>Nastavit velikost...</translation>
    </message>
</context>
<context>
    <name>RotateDialog</name>
    <message>
        <location filename="../rotatedialog.cpp" line="28"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../rotatedialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../rotatedialog.cpp" line="31"/>
        <source>Angle in degrees:</source>
        <translation>Úhel ve stupních:</translation>
    </message>
    <message>
        <location filename="../rotatedialog.cpp" line="33"/>
        <source>Rotate Object</source>
        <translation>Otočit předmět</translation>
    </message>
</context>
<context>
    <name>TargetNodeSizeDlg</name>
    <message>
        <location filename="../targetnodesizedlg.cpp" line="29"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../targetnodesizedlg.cpp" line="30"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../targetnodesizedlg.cpp" line="32"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../targetnodesizedlg.cpp" line="34"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../targetnodesizedlg.cpp" line="36"/>
        <source>Set target node size</source>
        <translation>Nastavit velikost cílového uzlu</translation>
    </message>
</context>
<context>
    <name>TrackPropertiesDialog</name>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="30"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="31"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="33"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="35"/>
        <source>Index:</source>
        <translation>Index:</translation>
    </message>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="37"/>
        <source>User track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trackpropertiesdialog.cpp" line="39"/>
        <source>Set track properties</source>
        <translation>Nastavit vlastnosti tratě</translation>
    </message>
</context>
</TS>
